==> fidget-0.0.5.tar.gz: fidget-0.0.5/fidget/widgets/__init__.py <==
from fidget.widgets.checkbox import FidgetCheckBox
from fidget.widgets.combo import FidgetCombo
from fidget.widgets.confirmer import FidgetConfirmer, FidgetQuestion, question
from fidget.widgets.converter import FidgetConverter, FidgetTransparentConverter
from fidget.widgets.multi_dict import FidgetDict
from fidget.widgets.edit_combo import FidgetEditCombo
from fidget.widgets.file_path import FidgetFilePath
from fidget.widgets.idiomatic_inner import inner_fidget
from fidget.widgets.image_path import FidgetImagePath
from fidget.widgets.label import FidgetLabel
from fidget.widgets.line import FidgetLineEdit
from fidget.widgets.matrix import FidgetMatrix
from fidget.widgets.minimalist import FidgetMinimal
from fidget.widgets.optional import FidgetOptional
from fidget.widgets.text import FidgetPlainTextEdit
from fidget.widgets.spin import FidgetSpin, FidgetDiscreteSpin
from fidget.widgets.stacked import FidgetStacked
from fidget.widgets.tabbed import FidgetTabs
from fidget.widgets.table import FidgetTable
from fidget.widgets.multi_tuple import FidgetTuple
from fidget.widgets.user_util import FidgetInt, FidgetFloat, FidgetComplex, SimpleLineEdit, template, SimplePlainEdit

# todo scrollable wrapper?
# todo multi-file widget
# todo directory widget
# todo multi-directory widget
# todo resource widget
# todo color widget
# todo script editor widget?
# todo slider widget
# todo date widget

# todo clear button to qlineedit

# todo use qtablewidget
# todo there's a lot of repeated code here

==> fidget-0.0.6.tar.gz: fidget-0.0.6/fidget/widgets/__init__.py <==
from fidget.widgets.checkbox import FidgetCheckBox
from fidget.widgets.combo import FidgetCombo
from fidget.widgets.confirmer import FidgetConfirmer, FidgetQuestion, question
from fidget.widgets.const_label import FidgetConst
from fidget.widgets.converter import FidgetConverter, FidgetTransparentConverter
from fidget.widgets.dict_ import FidgetDict
from fidget.widgets.edit_combo import FidgetEditCombo
from fidget.widgets.file_path import FidgetFilePath
from fidget.widgets.dir_path import FidgetDirPath
from fidget.widgets.multi_file import FidgetFilePaths
from fidget.widgets.idiomatic_inner import inner_fidget
from fidget.widgets.label import FidgetLabel
from fidget.widgets.line import FidgetLine
from fidget.widgets.matrix import FidgetMatrix
from fidget.widgets.minimalist import FidgetMinimal
from fidget.widgets.optional import FidgetOptional
from fidget.widgets.text import FidgetPlainText
from fidget.widgets.spin import FidgetSpin, FidgetDiscreteSpin
from fidget.widgets.stacked import FidgetStacked
from fidget.widgets.tabbed import FidgetTabs
from fidget.widgets.table import FidgetTable
from fidget.widgets.tuple_ import FidgetTuple
from fidget.widgets.user_util import FidgetInt, FidgetFloat, FidgetComplex, SimpleLineEdit, template, SimplePlainEdit

# todo scrollable wrapper?
# todo multi-file widget
# todo directory widget
# todo multi-directory widget
# todo resource widget
# todo color widget
# todo script editor widget?
# todo slider widget
# todo date widget
# todo preview wrapper

# todo clear button to qlineedit

# todo use qtablewidget
# todo there's a lot of repeated code here
